.. _background:

=========
About VOC
=========

VOC is a transpiler that takes Python 3.4+ source code, and compiles it into a
Java class file that can then be executed on a JVM.

It honors Python 3.4+ syntax and conventions, but also provides the ability to
reference objects and classes defined in Java code, and implement interfaces
defined in Java code.

.. toctree::
   :maxdepth: 1
   :glob:

   community
   faq
   install
   releases
   roadmap
